summaryrefslogtreecommitdiffstats
path: root/kaddressbook
diff options
context:
space:
mode:
Diffstat (limited to 'kaddressbook')
-rw-r--r--kaddressbook/kabcore.cpp4
-rw-r--r--kaddressbook/xxport/gnokii_xxport.cpp4
2 files changed, 4 insertions, 4 deletions
diff --git a/kaddressbook/kabcore.cpp b/kaddressbook/kabcore.cpp
index 263cb5f5..906c641c 100644
--- a/kaddressbook/kabcore.cpp
+++ b/kaddressbook/kabcore.cpp
@@ -1018,7 +1018,7 @@ TQString KABCore::getNameByPhone( const TQString &phone )
void KABCore::openLDAPDialog()
{
if ( !KProtocolInfo::isKnownProtocol( KURL( "ldap://localhost" ) ) ) {
- KMessageBox::error( mWidget, i18n( "Your KDE installation is missing LDAP "
+ KMessageBox::error( mWidget, i18n( "Your TDE installation is missing LDAP "
"support, please ask your administrator or distributor for more information." ),
i18n( "No LDAP IO Slave Available" ) );
return;
@@ -1413,7 +1413,7 @@ void KABCore::initActions()
mActionWhoAmI = new KAction( i18n( "Set as Personal Contact Data" ), "personal", 0, this,
TQT_SLOT( setWhoAmI() ), actionCollection(),
"edit_set_personal" );
- mActionWhoAmI->setWhatsThis( i18n( "Set the personal contact<p>The data of this contact will be used in many other KDE applications, so you do not have to input your personal data several times." ) );
+ mActionWhoAmI->setWhatsThis( i18n( "Set the personal contact<p>The data of this contact will be used in many other TDE applications, so you do not have to input your personal data several times." ) );
mActionCategories = new KAction( i18n( "Select Categories..." ), 0, this,
TQT_SLOT( setCategories() ), actionCollection(),
diff --git a/kaddressbook/xxport/gnokii_xxport.cpp b/kaddressbook/xxport/gnokii_xxport.cpp
index c432c7e5..0de310e9 100644
--- a/kaddressbook/xxport/gnokii_xxport.cpp
+++ b/kaddressbook/xxport/gnokii_xxport.cpp
@@ -21,7 +21,7 @@
*/
/*
Description:
- This filter allows you to import and export the KDE addressbook entries
+ This filter allows you to import and export the TDE addressbook entries
to/from a mobile phone, which is accessible via gnokii.
Gnokii homepage: http://www.gnokii.org
@@ -784,7 +784,7 @@ finish:
#ifdef __GNUC__
# warning "Please upgrade your gnokii installation to at least version 0.6.13"
# warning "Older gnokii versions below 0.6.13 are not binary compatible and"
# warning "prevents KDE users to upgrade gnokii to newer versions later."
#endif
/* OLD GNOKII LIBRARIES (< 0.6.13) */
@@ -784,7 +784,7 @@ finish:
# warning "Please upgrade your gnokii installation to at least version 0.6.13"
# warning "Older gnokii versions below 0.6.13 are not binary compatible and"
-# warning "prevents KDE users to upgrade gnokii to newer versions later."
+# warning "prevents TDE users to upgrade gnokii to newer versions later."
#endif
/* OLD GNOKII LIBRARIES (< 0.6.13) */